@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  gnome-print-config-dialog.h: A dialog to configure specific 
  *  printer settings.
@@ -71,7 +71,7 @@ gnome_print_config_dialog_get_type (void)
 			sizeof (GnomePrintConfigDialog),
 			0,
 			(GInstanceInitFunc) gnome_print_config_dialog_init,
-			NULL,
+			NULL
 		};
 		type = g_type_register_static (GTK_TYPE_DIALOG, "GnomePrintConfigDialog", &info, 0);
 	}
@@ -146,19 +146,26 @@ gnome_print_config_dialog_init (GnomePrintConfigDialog *gpd)
 static void
 gp_config_dialog_read_from_config (GnomePrintConfigDialog *gpd)
 {
-	gboolean tumble = FALSE;
-	gboolean duplex = FALSE;
+	gboolean duplex;
 
-	if (gpd->config == NULL)
-		return;
-
-	gnome_print_config_get_boolean (gpd->config, 
-					GNOME_PRINT_KEY_DUPLEX, &duplex);
-	gnome_print_config_get_boolean (gpd->config, 
-					GNOME_PRINT_KEY_TUMBLE, &tumble);
-
-	gtk_toggle_button_set_active ((GtkToggleButton *) gpd->duplex, duplex);
-	gtk_toggle_button_set_active ((GtkToggleButton *) gpd->tumble, tumble);	
+	if (gpd->config != NULL &&
+	    gnome_print_config_get_boolean (gpd->config, 
+					    GNOME_PRINT_KEY_DUPLEX, &duplex)) {
+		gboolean tumble = FALSE;
+		gnome_print_config_get_boolean (gpd->config, 
+			GNOME_PRINT_KEY_TUMBLE, &tumble);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gpd->duplex), duplex);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gpd->tumble), tumble);	
+		gtk_widget_show (gpd->duplex);
+		gtk_widget_show (gpd->duplex_image);
+		gtk_widget_show (gpd->tumble);
+		gtk_widget_show (gpd->tumble_image);
+	} else {
+		gtk_widget_hide (gpd->duplex);
+		gtk_widget_hide (gpd->duplex_image);
+		gtk_widget_hide (gpd->tumble);
+		gtk_widget_hide (gpd->tumble_image);
+	}
 }
 
 
